@@ -1,13 +1,13 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: keyfiles.c 484 2010-02-21 15:37:06Z liske $
+ * $Id: keyfiles.c 538 2010-09-25 13:57:25Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008-2009 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2010 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -232,12 +232,6 @@ CfgFile *loadConfig (char *filename)
   return (NULL);
  }
 
- lcfg->use_screen = g_key_file_get_integer(keyfile, "Screen", "Enabled", &error);
- if (error) {
-   lcfg->use_screen = g_file_test(SCREEN_BINARY, G_FILE_TEST_IS_EXECUTABLE);
-   g_clear_error(&error);
- }
-
  lcfg->dump_screen = !g_key_file_get_boolean(keyfile, "Screen", "NoDumps", &error);
  if (error) {
    lcfg->dump_screen = TRUE;
