@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: stats.h 200 2008-08-27 18:30:15Z liske $
+ * $Id: stats.h 269 2009-01-18 20:23:43Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -39,9 +39,8 @@ freeUpdates(GList *updates);
 
 gboolean refreshStats(GList *);
 gboolean setStatsFileFromIOC(GIOChannel *, GIOCondition, gpointer);
-gchar *getStatsFileName(const gchar *);
-gchar *getStatsFile(const gchar *);
-gboolean removeStatsFile(const gchar *);
+gchar *getStatsFileName(const HostNode *);
+gboolean prepareStatsFile(HostNode *n);
 gboolean getUpdatesFromStat(HostNode *);
 void refreshStatsOfNode(gpointer);
 
